==> ui-18.3.4.tgz: package/components/radio/Radio.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import { useState } from 'react';
import { checkNodeExist, getClassName } from '@react-devui/utils';
import { useWave, useGeneralContext, useDValue } from '../../hooks';
import { registerComponentMate } from '../../utils';
import { DBaseDesign } from '../_base-design';
import { DBaseInput } from '../_base-input';
import { DFocusVisible } from '../_focus-visible';
import { useFormControl } from '../form';
import { useComponentConfig, usePrefixConfig } from '../root';
import { DRadioGroup } from './RadioGroup';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DRadio' });
export const DRadio = (props) => {
    const _a = useComponentConfig(COMPONENT_NAME, props), { children, dRef, dFormControl, dModel, dDisabled = false, dInputRender, onModelChange, __type } = _a, restProps = __rest(_a, ["children", "dRef", "dFormControl", "dModel", "dDisabled", "dInputRender", "onModelChange", "__type"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gSize, gDisabled } = useGeneralContext();
    //#endregion
    const [waveNode, wave] = useWave();
    const [focusVisible, setFocusVisible] = useState(false);
    const formControlInject = useFormControl(dFormControl);
    const [checked, changeChecked] = useDValue(false, dModel, onModelChange, undefined, formControlInject);
    const disabled = dDisabled || gDisabled || (dFormControl === null || dFormControl === void 0 ? void 0 : dFormControl.control.disabled);
    return (_jsx(DBaseDesign, Object.assign({ dComposeDesign: {
            active: checked || focusVisible,
            disabled: disabled,
        }, dFormDesign: false }, { children: ({ render: renderBaseDesign }) => renderBaseDesign(_jsxs("label", Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}radio`, {
                [`${dPrefix}radio--button`]: __type,
                [`${dPrefix}radio--button-${__type}`]: __type,
                [`${dPrefix}radio--${gSize}`]: gSize,
                'is-checked': checked,
                'is-focus-visible': focusVisible,
                'is-disabled': disabled,
            }), onClick: (e) => {
                var _a;
                (_a = restProps.onClick) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
                if (__type === 'fill' || __type === 'outline') {
                    wave(`var(--${dPrefix}color-primary)`);
                }
            } }, { children: [_jsx("div", Object.assign({ className: `${dPrefix}radio__input-wrapper` }, { children: _jsx(DFocusVisible, Object.assign({ onFocusVisibleChange: setFocusVisible }, { children: ({ render: renderFocusVisible }) => (_jsx(DBaseInput, Object.assign({ dFormControl: dFormControl, dLabelFor: true }, { children: ({ render: renderBaseInput }) => {
                                const input = renderFocusVisible(renderBaseInput(_jsx("input", { ref: dRef === null || dRef === void 0 ? void 0 : dRef.input, className: `${dPrefix}radio__input`, type: "radio", checked: checked, disabled: disabled, "aria-checked": checked, onChange: () => {
                                        changeChecked(true);
                                    } })));
                                return isUndefined(dInputRender) ? input : dInputRender(input);
                            } }))) })) })), checkNodeExist(children) && _jsx("div", Object.assign({ className: `${dPrefix}radio__label` }, { children: children })), waveNode] }))) })));
};
DRadio.Group = DRadioGroup;

==> ui-18.3.7.tgz: package/components/radio/Radio.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import { useState } from 'react';
import { checkNodeExist, getClassName } from '@react-devui/utils';
import { useWave, useGeneralContext, useDValue } from '../../hooks';
import { registerComponentMate } from '../../utils';
import { DBaseDesign } from '../_base-design';
import { DBaseInput } from '../_base-input';
import { DFocusVisible } from '../_focus-visible';
import { useFormControl } from '../form';
import { useComponentConfig, usePrefixConfig } from '../root';
import { DRadioGroup } from './RadioGroup';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DRadio' });
export const DRadio = (props) => {
    const _a = useComponentConfig(COMPONENT_NAME, props), { children, dRef, dFormControl, dModel, dDisabled = false, dInputRender, onModelChange, __type } = _a, restProps = __rest(_a, ["children", "dRef", "dFormControl", "dModel", "dDisabled", "dInputRender", "onModelChange", "__type"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gSize, gDisabled } = useGeneralContext();
    //#endregion
    const [waveNode, wave] = useWave();
    const [focusVisible, setFocusVisible] = useState(false);
    const formControlInject = useFormControl(dFormControl);
    const [checked, changeChecked] = useDValue(false, dModel, onModelChange, undefined, formControlInject);
    const disabled = dDisabled || gDisabled || (dFormControl === null || dFormControl === void 0 ? void 0 : dFormControl.control.disabled);
    return (_jsx(DBaseDesign, Object.assign({ dComposeDesign: __type
            ? {
                active: checked || focusVisible,
                disabled: disabled,
            }
            : false, dFormDesign: false }, { children: ({ render: renderBaseDesign }) => renderBaseDesign(_jsxs("label", Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}radio`, {
                [`${dPrefix}radio--button`]: __type,
                [`${dPrefix}radio--button-${__type}`]: __type,
                [`${dPrefix}radio--${gSize}`]: gSize,
                'is-checked': checked,
                'is-focus-visible': focusVisible,
                'is-disabled': disabled,
            }), onClick: (e) => {
                var _a;
                (_a = restProps.onClick) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
                if (__type === 'fill' || __type === 'outline') {
                    wave(`var(--${dPrefix}color-primary)`);
                }
            } }, { children: [_jsx("div", Object.assign({ className: `${dPrefix}radio__input-wrapper` }, { children: _jsx(DFocusVisible, Object.assign({ onFocusVisibleChange: setFocusVisible }, { children: ({ render: renderFocusVisible }) => (_jsx(DBaseInput, Object.assign({ dFormControl: dFormControl, dLabelFor: true }, { children: ({ render: renderBaseInput }) => {
                                const input = renderFocusVisible(renderBaseInput(_jsx("input", { ref: dRef === null || dRef === void 0 ? void 0 : dRef.input, className: `${dPrefix}radio__input`, type: "radio", checked: checked, disabled: disabled, "aria-checked": checked, onChange: () => {
                                        changeChecked(true);
                                    } })));
                                return isUndefined(dInputRender) ? input : dInputRender(input);
                            } }))) })) })), checkNodeExist(children) && _jsx("div", Object.assign({ className: `${dPrefix}radio__label` }, { children: children })), waveNode] }))) })));
};
DRadio.Group = DRadioGroup;
